==> CITAN_2011.02-1.tar.gz: CITAN/man/pareto2.confint.rho.approx.upper.Rd <==
\name{pareto2.confint.rho.approx.upper}
\alias{pareto2.confint.rho.approx.upper}
\title{Right-sided approximate confidence interval for the kappa-index}
\usage{pareto2.confint.rho.approx.upper(v, kappa, kappaInvDer, s, n,
    conf.level=0.95)}
\description{Computes the approximate (asymptotic) right-sided confidence interval for the kappa-index of
a probability distribution in an \eqn{(X_1,\dots,X_n)} i.i.d. Pareto-type II
model with known scale parameter \eqn{s\ge 1}.
The confidence interval bases on the observed value
of S-statistic w.r.t. to the given control function \eqn{\kappa}.}
\details{For more information see man page on  \code{\link{rho.get}}, \code{\link{Sstat}} and the paper (Gagolewski, Grzegorzewski, 2010).}
\references{Gagolewski M., Grzegorzewski P., S-Statistics and Their Basic Properties, In: Borgelt C. et al (Eds.),
Combining Soft Computing and Statistical Methods in Data Analysis, Springer-Verlag, 2010, 281-288.\cr}
\value{Upper bound of the confidence interval.}
\seealso{\code{\link{ppareto2}}, \code{\link{pareto2.confint.rho}}, \code{\link{Sstat}},
\code{\link{pareto2.confint.rho.approx.lower}},
\code{\link{pareto2.confint.rho.approx}}, \code{\link{rho.get}}}
\arguments{\item{v}{observed value of the S-statistic w.r.t. \eqn{\kappa}.}
\item{kappa}{an increasing function, \eqn{\kappa}, a so-called control function.}
\item{kappaInvDer}{the derivative of the inverse of \eqn{\kappa}.}
\item{s}{scale parameter, \eqn{s\ge 1}.}
\item{n}{sample size.}
\item{conf.level}{confidence level; defaults 0.95.}}

==> CITAN_2011.03-1.tar.gz: CITAN/man/pareto2.confint.rho.approx.upper.Rd <==
\name{pareto2.confint.rho.approx.upper}
\alias{pareto2.confint.rho.approx.upper}
\title{Right-sided approximate confidence interval for the kappa-index}
\usage{pareto2.confint.rho.approx.upper(v, kappa, kappaInvDer, s, n,
    conf.level=0.95)}
\description{Computes the approximate (asymptotic) right-sided confidence interval for the kappa-index of
a probability distribution in an \eqn{(X_1,\dots,X_n)} i.i.d. Pareto-type II
model with known scale parameter \eqn{s>0}.
The confidence interval bases on the observed value
of S-statistic w.r.t. to the given control function \eqn{\kappa}.}
\details{For more information see man page on  \code{\link{rho.get}}, \code{\link{Sstat}} and the paper (Gagolewski, Grzegorzewski, 2010).}
\references{Gagolewski M., Grzegorzewski P., S-Statistics and Their Basic Properties, In: Borgelt C. et al (Eds.),
Combining Soft Computing and Statistical Methods in Data Analysis, Springer-Verlag, 2010, 281-288.\cr}
\value{Upper bound of the confidence interval.}
\seealso{\code{\link{ppareto2}}, \code{\link{pareto2.confint.rho}}, \code{\link{Sstat}},
\code{\link{pareto2.confint.rho.approx.lower}},
\code{\link{pareto2.confint.rho.approx}}, \code{\link{rho.get}}}
\arguments{\item{v}{observed value of the S-statistic w.r.t. \eqn{\kappa}.}
\item{kappa}{an increasing function, \eqn{\kappa}, a so-called control function.}
\item{kappaInvDer}{the derivative of the inverse of \eqn{\kappa}.}
\item{s}{scale parameter, \eqn{s>0}.}
\item{n}{sample size.}
\item{conf.level}{confidence level; defaults 0.95.}}
